/**
 * Copyright (c) 2011, iPlant Collaborative, University of Arizona, Cold Spring Harbor Laboratories, University of Texas at Austin
 * This software is licensed; see the accompanying license file for terms.
 */
package info.sswap.util.jcurl;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;

import com.clarkparsia.utils.web.Method;
import com.clarkparsia.utils.web.Request;
import com.clarkparsia.utils.web.Response;
import com.google.common.io.ByteStreams;

public class JCurl {
	private static void displayUsage() {
		System.err.println("Usage:");
		System.err.println("java info.sswap.util.jcurl.JCurl URL jsonFilename");
	}
	
	private static void post(URL url, InputStream is) throws IOException {
		Request request = new Request(Method.POST, url);
		request.addHeader("Content-Type", "application/json");
		request.addHeader("Accept", "application/rdf+xml");
		request.setBody(is);
		
		Response response = request.execute();
		
		if (!response.hasErrorCode()) {		
			ByteStreams.copy(response.getContent(), System.out);
		}
		else {
			System.err.println(String.format("Remote service (%s) returned a HTTP Error code: ", url.toString()) + response.getResponseCode());
			System.exit(1);
		}
	}
	
	public static void main(String[] args) {
		try {
			if (args.length != 2) {
				System.err.println("Invalid number of parameters");
				displayUsage();
				System.exit(1);
			}
			
			String urlString = args[0];
			String jsonFilename = args[1];
			
			URL url = null;
			
			try {
				url = new URL(urlString);
			}
			catch (MalformedURLException e) {
				System.err.println("Invalid URL: " + e.getMessage());
				System.exit(1);
			}			
			
			FileInputStream fis = new FileInputStream(jsonFilename);
			
			post(url, fis);
			
			fis.close();
		}
		catch (Throwable e) {
			System.err.println(e.getMessage());
			System.exit(1);
		}
	}
}
